@@ -2,9 +2,10 @@
 
 namespace Wallabag\CoreBundle\Helper;
 
-use Symfony\Component\Routing\Router;
+use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
 use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;
 use Wallabag\CoreBundle\Entity\Config;
+use Wallabag\UserBundle\Entity\User;
 
 /**
  * Manage redirections to avoid redirecting to empty routes.
@@ -14,7 +15,7 @@ class Redirect
     private $router;
     private $tokenStorage;
 
-    public function __construct(Router $router, TokenStorageInterface $tokenStorage)
+    public function __construct(UrlGeneratorInterface $router, TokenStorageInterface $tokenStorage)
     {
         $this->router = $router;
         $this->tokenStorage = $tokenStorage;
@@ -31,7 +32,7 @@ class Redirect
     {
         $user = $this->tokenStorage->getToken() ? $this->tokenStorage->getToken()->getUser() : null;
 
-        if (null === $user || !\is_object($user)) {
+        if (!$user instanceof User) {
             return $url;
         }
 
