@@ -32,12 +32,6 @@ class SecurityControllerTest extends WallabagCoreTestCase
     {
         $client = $this->getTestClient();
 
-        if (!$client->getContainer()->getParameter('twofactor_auth')) {
-            $this->markTestSkipped('twofactor_auth is not enabled.');
-
-            return;
-        }
-
         $client->followRedirects();
 
         $em = $client->getContainer()->get(EntityManagerInterface::class);
@@ -65,12 +59,6 @@ class SecurityControllerTest extends WallabagCoreTestCase
     {
         $client = $this->getTestClient();
 
-        if (!$client->getContainer()->getParameter('twofactor_auth')) {
-            $this->markTestSkipped('twofactor_auth is not enabled.');
-
-            return;
-        }
-
         $client->followRedirects();
 
         $em = $client->getContainer()->get(EntityManagerInterface::class);
